==> 2.0.0.tar.gz: lib/src/sdk_package_dependency_spec/sdk_package_dependency_spec.dart <==
/*
 * MIT License
 *
 * Copyright (c) 2019 Alexei Sintotski
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 *  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 *
 */

import 'package:functional_data/functional_data.dart' hide Optional;
import 'package:meta/meta.dart';
import 'package:plain_optional/plain_optional.dart';

part 'sdk_package_dependency_spec.g.dart';

// ignore_for_file: annotate_overrides

/// Package coming from an SDK (https://dart.dev/tools/pub/dependencies)
@immutable
@FunctionalData()
class SdkPackageDependencySpec extends $SdkPackageDependencySpec {
  /// Default constructor
  const SdkPackageDependencySpec({
    @required this.package,
    @required this.sdk,
    this.version = const Optional.none(),
  });

  final String package;
  final String sdk;
  final Optional<String> version;
}

==> 2.0.1.tar.gz: lib/src/sdk_package_dependency_spec/sdk_package_dependency_spec.dart <==
/*
 * MIT License
 *
 * Copyright (c) 2019 Alexei Sintotski
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 *  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 *
 */

import 'package:functional_data/functional_data.dart';
import 'package:meta/meta.dart';
import 'package:plain_optional/plain_optional.dart';

part 'sdk_package_dependency_spec.g.dart';

// ignore_for_file: annotate_overrides

/// Package coming from an SDK (https://dart.dev/tools/pub/dependencies)
@immutable
@FunctionalData()
class SdkPackageDependencySpec extends $SdkPackageDependencySpec {
  /// Default constructor
  const SdkPackageDependencySpec({
    @required this.package,
    @required this.sdk,
    this.version = const Optional.none(),
  });

  final String package;
  final String sdk;
  final Optional<String> version;
}
